package BlogRebuilderApp;
use MT::App;
use base qw( MT::App );

use strict;

use vars qw( $VERSION );
my $VERSION = "1.0.1";

use MT::Permission;
use MT::Template;
use Data::Dumper;

sub init {
  my $app = shift;
  $app->SUPER::init (@_) or return;
  $app->add_methods (
      default	=> \&default,
      rebuild	=> \&hdlr_rebuild,
      done      => \&done,
      );
  $app->{default_mode} = 'default';
  $app->{template_dir} = 'cms';
  $app->{plugin_template_path} = File::Spec->catdir ('plugins', 'BlogRebuilder', 'tmpl');
  $app->{requires_login} = 1;
  $app->{user_class} = 'MT::Author';

  $app;
}

sub pre_run {
  my $app = shift;
  $app->SUPER::pre_run ();
}

sub default {
    my ($app) = @_;
    $app->user->is_superuser
        or return $app->error($app->translate("Permission denied."));
    my @blogs = MT::Blog->load;
    my @blog_list = map { 
        my $perm = MT::Permission->load({blog_id => $_->id, author_id => $app->user->id});
        my $can_rebuild = $perm ? $perm->can_rebuild : 0;
        {ID => $_->id, NAME => $_->name, CAN_REBUILD => $can_rebuild}
    } @blogs;
    my %params = (
        BLOG_LIST => \@blog_list,
        APP_URL => $app->uri,
        SYSTEM_OVERVIEW_NAV => 1,
    );
    return $app->build_page ('default.tmpl', \%params);
}

sub hdlr_rebuild {
    my ($app) = @_;
    $app->user->is_superuser
        or return $app->error($app->translate("Permission denied."));

    my $q = $app->{query};

    my @target = $q->param('blog_id');
    scalar @target 
        or return $app->redirect($app->path."plugins/BlogRebuilder/blog-rebuilder.cgi?__mode=done");
    my $target = pop @target;
    my $blog = MT::Blog->load({id => $target}) or return $app->error("Couldn't load Blog");

    if($target) {
        $app->rebuild('BlogID' => $target);
        my $next =  $app->path."plugins/BlogRebuilder/blog-rebuilder.cgi?__mode=rebuild&". join '&', map {"blog_id=$_"} @target;
        my %params = (
            NEXT => $next,
            BLOG_NAME => $blog->name,
        );
        return $app->build_page('rebuild.tmpl', \%params);
    }
}


sub done {
    my ($app) = @_;
    my %params;
    return $app->build_page('done.tmpl', \%params);

}
1;